@@ -4,10 +4,6 @@ library(stringr)
 library(rvest)
 library(glue)
 
-expect_missing <- function(object) {
-  expect_true(is.na(object))
-}
-
 test_that("md_link can create a valid <href> tag (ex. 493)", {
   # https://github.github.com/gfm/#example-493
   lines <- md_link("link", "/url", "title")
@@ -32,7 +28,8 @@ test_that("md_link can create a valid <href> tag (ex. 493)", {
 })
 
 test_that("md_link can create <href> tags with a named vector", {
-  lines <- md_link(x = c("link" = "/url"), title = "title")
+  # no way to use title too
+  lines <- md_link(link = "/url")
   lines %>%
     md_convert() %>%
     read_html() %>%
@@ -45,16 +42,16 @@ test_that("md_link can create <href> tags with a named vector", {
     html_node("a") %>%
     html_attr("href") %>%
     expect_equal("/url")
-  lines %>%
-    md_convert() %>%
-    read_html() %>%
-    html_node("a") %>%
-    html_attr("title") %>%
-    expect_equal("title")
+  # lines %>%
+  #   md_convert() %>%
+  #   read_html() %>%
+  #   html_node("a") %>%
+  #   html_attr("title") %>%
+  #   expect_equal("title")
 })
 
 test_that("md_link can create <href> tags with a named vector", {
-  lines <- md_link(x = c("link" = "/url"))
+  lines <- md_link(link = "/url")
   lines %>%
     md_convert() %>%
     read_html() %>%
@@ -94,7 +91,7 @@ test_that("md_link can create a valid <href> without title (ex. 494)", {
 
 test_that("md_reference can create an <href> tag (ex. 535)", {
   # https://github.github.com/gfm/#example-535
-  lines <- md_reference("bar", "/url", "title")
+  lines <- md_reference("bar" = "/url \"title\"")
   md_paragraph("[foo][bar]", lines) %>%
     md_convert() %>%
     read_html() %>%
@@ -118,17 +115,22 @@ test_that("md_reference can create an <href> tag (ex. 535)", {
     expect_equal("title")
 })
 
-test_that("md_reference can create an <href> tag without title (ex. 535)", {
+test_that("md_label and md_reference can create an <href> tag (ex. 535)", {
   # https://github.github.com/gfm/#example-535
-  lines <- md_reference("bar", "/url")
-  md_paragraph("[foo][bar]", lines) %>%
+  md_paragraph(
+    md_label(bar = "foo"),
+    md_reference(bar = "/url")
+  ) %>%
     md_convert() %>%
     read_html() %>%
     html_node("p") %>%
     html_node("a") %>%
     html_text(trim = TRUE) %>%
     expect_equal("foo")
-  md_paragraph("[foo][bar]", lines) %>%
+  md_paragraph(
+    md_label(bar = "foo"),
+    md_reference(bar = "/url")
+  ) %>%
     md_convert() %>%
     read_html() %>%
     html_node("p") %>%
@@ -136,3 +138,28 @@ test_that("md_reference can create an <href> tag without title (ex. 535)", {
     html_attr("href") %>%
     expect_equal("/url")
 })
+
+test_that("md_label and md_reference can create an <href> tag (ex. 535)", {
+  # https://github.github.com/gfm/#example-535
+  md_paragraph(
+    md_label("foo", "bar"),
+    md_reference("bar", "/url")
+  ) %>%
+    md_convert() %>%
+    read_html() %>%
+    html_node("p") %>%
+    html_node("a") %>%
+    html_text(trim = TRUE) %>%
+    expect_equal("foo")
+  md_paragraph(
+    md_label("foo", "bar"),
+    md_reference("bar", "/url")
+  ) %>%
+    md_convert() %>%
+    read_html() %>%
+    html_node("p") %>%
+    html_node("a") %>%
+    html_attr("href") %>%
+    expect_equal("/url")
+})
+
